// Version December 15, 2023. Replication codes
// Set one of the options below to 1 to generate figures/tables and save data for other files

capture mkdir output

global do_figure_1 = 1
global do_figure_2 = 0
global do_appendix_figure_2 = 0
global do_appendix_figure_3 = 0
global do_appendix_figure_5 = 0
global do_appendix_table_1 = 0


if $do_figure_1 == 1 {
  global models_to_run = "1" 
  global do_global_rates_plot = 1 
  global do_global_rates_plot_hp = 0 
  global do_event_study_plot = 0
}

if $do_figure_2 == 1 {
  global models_to_run = "1" 
  global do_global_rates_plot = 1 
  global do_global_rates_plot_hp = 0 
  global do_event_study_plot = 1
}

if $do_appendix_figure_2 == 1 {
  global models_to_run = "2" 
  global do_global_rates_plot = 0 
  global do_global_rates_plot_hp = 1 
  global do_event_study_plot = 1
}

if $do_appendix_figure_3 == 1 {
  global models_to_run = "3" 
  global do_global_rates_plot = 0 
  global do_global_rates_plot_hp = 0 
  global do_event_study_plot = 1
}

if $do_appendix_figure_5 == 1 {
  global models_to_run = "4" 
  global do_global_rates_plot = 0 
  global do_global_rates_plot_hp = 0 
  global do_event_study_plot = 1
}

if $do_appendix_table_1 == 1 {
  global models_to_run = "0" 
  global do_global_rates_plot = 0 
  global do_global_rates_plot_hp = 0 
  global do_event_study_plot = 0
}



global periodnum_pre = 2 // # of periods before episode you want to project
global periodnum_post = 10 // # of periods after episode you want to project


clear
set more off
set scheme s1color, permanently
use macrodata_newcore, clear




gen quarter_sq = quarter*quarter
gen DOIL = oil_usd/L4.oil_usd-1

// Create changes in variables 
gen d1_u = unemp - L1.unemp
gen d4_u = unemp - L4.unemp
gen d8_u = unemp - L8.unemp
gen f1_u = F1.unemp - unemp
gen f4_u = F4.unemp - unemp
gen f8_u = F8.unemp - unemp

gen d1_p = INFL4-L1.INFL4
gen d2_p = INFL4-L2.INFL4
gen d4_p = INFL4-L4.INFL4
gen d8_p = INFL4-L8.INFL4
gen f1_p = F1.INFL4-INFL4
gen f2_p = F2.INFL4-INFL4
gen f4_p = F4.INFL4-INFL4
gen f8_p = F8.INFL4-INFL4

gen d1_r = INTRATE-L1.INTRATE
gen d2_r = INTRATE-L2.INTRATE
gen d4_r = INTRATE-L4.INTRATE
gen d6_r = INTRATE-L6.INTRATE
gen d8_r = INTRATE-L8.INTRATE
gen f1_r = F1.INTRATE-INTRATE
gen f2_r = F2.INTRATE-INTRATE
gen f4_r = F4.INTRATE-INTRATE
gen f6_r = F6.INTRATE-INTRATE
gen f8_r = F8.INTRATE-INTRATE





gen dum_o=0
replace dum_o=1 if INTRATE~=. & UNEMPLO~=. & INFL4~=.



gen lbankprice = 100*log(bankprice/cpi_index)
regress lbankprice i.country#c.quarter i.country
predict lbankpriceresid if lbankprice~=., resid
gen BANKNW = lbankpriceresid
label var BANKNW "Global Banks Stock Price"
label var lbankprice "Global Banks Stock Price"




gen GDPVAR = 100*ln_gdp_q
gen INTRATE0 = INTRATE
gen UNEMPLO0 = UNEMPLO
gen INFL0 = INFL4

gen CONSVAR = 100*ln_cons_q
gen INVVAR = 100*ln_inv_q
gen NXVAR = 100*nx_real_q
gen XRVAR = 100*log(reer_bruegel)
gen NXTRADEVAR = 100*nx_trade
gen TRADEGDPVAR = 100*trade_gdp







keep if tin($t1p,$t2p)

list country quarter INVVAR D.INVVAR if abs(D.INVVAR)>50 & D.INVVAR~=. & dum_afe==1
replace INVVAR=. if abs(D.INVVAR)>50 & D.INVVAR~=. & dum_afe==1

list country quarter NXVAR D.NXVAR if abs(D.NXVAR)>50 & D.NXVAR~=. & dum_afe==1
replace NXVAR=. if abs(D.NXVAR)>50 & D.NXVAR~=. & dum_afe==1

format UNEMPLO %5.1f
format GDPVAR %5.1f






//---------------------------------
// TABLE A-1 construction
//---------------------------------

foreach var of varlist UNEMPLO INFL4 INTRATE GDPVAR MPSHOCK_LIT BANKNW ///
SPREAD cspread cspread_gm cspread_gfd MPSHOCK_RR_US MPSHOCK_CH_UK CONSVAR INVVAR NXVAR {

sort country quarter
gen first_`var' = 0
replace first_`var' = 1 if `var'~=. & F.`var'~=. & (L.`var'==. | tin(1960q1,1960q1))
bysort country (quarter) : gen cum_first_`var' = sum(first_`var')

gen last_`var' = 0
replace last_`var' = 1 if `var'~=. & L.`var'~=. & (F.`var'==. | tin(2022q3,2022q3))
bysort country (quarter) : gen cum_last_`var' = sum(last_`var')
bysort country (quarter) : egen max_cum_last_`var' = max(cum_last_`var')

gen temp_q_f_`var'0 = quarter if first_`var'==1 & cum_first_`var'==1
gen temp_q_l_`var'0 = quarter if last_`var'==1 & cum_last_`var'==max_cum_last_`var'
egen qf_`var' = mean(temp_q_f_`var'0), by(country)
egen ql_`var' = mean(temp_q_l_`var'0), by(country)

generate qqq_`var' = string(qf_`var', "%tq") + " " + string(ql_`var', "%tq")

}


format qf* ql* %tq
drop temp_q*



if $do_appendix_table_1 == 1 {

global varlist_mshocks = "qqq_MPSHOCK_LIT qqq_MPSHOCK_RR_US qqq_MPSHOCK_CH_UK qqq_INFL qqq_GDPVAR" 
list country $varlist_mshocks ///
if tin(2000q1,2000q1) & (dum_afe==1 | dum_us==1), ab(7) sep(5)

global varlist_table = "qqq_UNEMPLO qqq_INFL qqq_INTRATE qqq_GDPVAR qqq_SPREAD qqq_BANKNW" 

list country $varlist_table ///
if tin(2000q1,2000q1) & (dum_afe==1 | dum_us==1), ab(7) sep(5)


listtex country $varlist_table ///
if tin(2000q1,2000q1) & (dum_afe==1 | dum_us==1), ///
type rstyle(tabular) ///
head("\begin{tabular}{ccccccc}") ///
foot("\end{tabular}")


list country $varlist_table  ///
if tin(2000q1,2000q1) & dum_eme_plus==1, ab(7) sep(5)

listtex country $varlist_table ///
if tin(2000q1,2000q1) & dum_eme_plus==1, ///
type rstyle(tabular) ///
head("\begin{tabular}{ccccccc}") ///
foot("\end{tabular}")

display("I stopped here for the table")
stop


}





/// CONSTRUCT GLOBAL VARIABLES

foreach v in ///
	INTRATE INFL4 UNEMPLO {
	gen weight_`v' = ngdp_usd
	egen sum_weight_`v' = sum(weight_`v') if `v'~=. & weight_`v'~=. & (dum_afe==1 | dum_us==1), by(quarter)
	gen share_weight_`v' = weight_`v'/sum_weight_`v'
	asgen `v'_W = `v' if `v'~=., weights(share_weight_`v') by(quarter)
}


/// CONSTRUCT FOREIGN VARIABLES

foreach v in ///
	INTRATE INFL4 UNEMPLO GDPVAR NXVAR XRVAR BANKNW INVVAR CONSVAR {
	gen weight_for_`v' = ngdp_usd
	egen sum_weight_for_`v' = sum(weight_for_`v') if `v'~=. & weight_for_`v'~=. & (dum_afe==1), by(quarter)
	gen share_weight_for_`v' = weight_for_`v'/sum_weight_for_`v'
	asgen `v'_F = `v' if `v'~=., weights(share_weight_for_`v') by(quarter)

	tsfilter bk `v'_BP   = `v' 	 if dum_us==1, minperiod(6) maxperiod(32)
	tsfilter bk `v'_F_BP = `v'_F if dum_us==1, minperiod(6) maxperiod(32)

	tsfilter hp `v'_HP   = `v' 	 if dum_us==1, smooth(1600)	
	tsfilter hp `v'_F_HP = `v'_F if dum_us==1, smooth(1600)

}

export excel quarter ///
	INTRATE INFL4 UNEMPLO GDPVAR NXVAR XRVAR BANKNW INVVAR CONSVAR ///
	INTRATE_F INFL4_F UNEMPLO_F GDPVAR_F NXVAR_F XRVAR_F BANKNW_F INVVAR_F CONSVAR_F ///
	using "output/data_global_aggregates" if dum_us==1, sheetreplace firstrow(variables) datestring("%-tqCCYY-!Qq")

export excel quarter ///
	INTRATE_BP INFL4_BP UNEMPLO_BP GDPVAR_BP NXVAR_BP XRVAR_BP BANKNW_BP INVVAR_BP CONSVAR_BP ///
	INTRATE_F_BP INFL4_F_BP UNEMPLO_F_BP GDPVAR_F_BP NXVAR_F_BP XRVAR_F_BP BANKNW_F_BP INVVAR_F_BP CONSVAR_F_BP ///
	using "output/data_global_aggregates_bp" if dum_us==1, sheetreplace firstrow(variables) datestring("%-tqCCYY-!Qq")

export excel quarter ///
	INTRATE_HP INFL4_HP UNEMPLO_HP GDPVAR_HP NXVAR_HP XRVAR_HP BANKNW_HP INVVAR_HP CONSVAR_HP ///
	INTRATE_F_HP INFL4_F_HP UNEMPLO_F_HP GDPVAR_F_HP NXVAR_F_HP XRVAR_F_HP BANKNW_F_HP INVVAR_F_HP CONSVAR_F_HP ///
	using "output/data_global_aggregates_hp" if dum_us==1, sheetreplace firstrow(variables) datestring("%-tqCCYY-!Qq")

	
	
	
sum INTRATE INFL4 UNEMPLO GDPVAR NXVAR XRVAR BANKNW INVVAR CONSVAR ///
INTRATE_F INFL4_F UNEMPLO_F GDPVAR_F NXVAR_F XRVAR_F BANKNW_F INVVAR_F CONSVAR_F if dum_us==1

sum INTRATE_BP INFL4_BP UNEMPLO_BP GDPVAR_BP NXVAR_BP XRVAR_BP BANKNW_BP INVVAR_BP CONSVAR_BP ///
INTRATE_F_BP INFL4_F_BP UNEMPLO_F_BP GDPVAR_F_BP NXVAR_F_BP XRVAR_F_BP BANKNW_F_BP INVVAR_F_BP CONSVAR_F_BP if dum_us==1

	

	

	
	
// Construct monetary shocks

// Country Taylor rule regressions, 2 lags
reg INTRATE ///
i.country ///
i.country#c.quarter ///
i.country#c.quarter#c.quarter ///
i.country#c.L(1/2).DOIL ///
i.country#c.L(1/2).INTRATE ///
i.country#c.L(1/2).UNEMPLO ///
i.country#c.L(1/2).XRVAR ///
i.country#c.L(1/2).INFL4 ///
if tin($t1,$t3)
quietly predict MSI, residuals
quietly predict INTRATEHAT, xb
label var MSI "Monetary Shock from Taylor rule, ppt"




// Country Taylor rule regressions, 2 lags
reg INTRATE ///
i.country ///
i.country#c.quarter ///
i.country#c.quarter#c.quarter ///
i.country#c.L(1/2).DOIL ///
i.country#c.L(1/2).INTRATE ///
i.country#c.L(1/2).UNEMPLO ///
i.country#c.L(1/2).XRVAR ///
i.country#c.L(1/2).INFL4 ///
i.country#c.L(1/2).INTRATE_W ///
i.country#c.L(1/2).INFL4_W ///
i.country#c.L(1/2).UNEMPLO_W ///
if tin($t1,$t3)
quietly predict MSIG, residuals
quietly predict INTRATEHATG, xb
label var MSIG "Monetary Shock from Taylor rule, World Controls"

	

save output/macrodata_newcore_temp, replace





///------------------------------------
global remove_condition = " "

/// Loop across alternatives
	
foreach imodel of numlist $models_to_run {

use output/macrodata_newcore_temp, clear


if `imodel'==1 {
	// Baseline IRF with GDP components
	global numvar = 12
	global iloop_pre=0
	global iloop_post=8
	global remove_contiguous_tightenings=1
	keep if dum_us==1 | dum_afe==1
	global country_condition = "MSI>=0.25  & MSI~=." 
	global world_condition   = "d4_r_global>=0.25 & (f6_r_global<0 | f6_r_global==.)"
	global macro_controls    = " "
	global gtitle			 = "Baseline"
}


if `imodel'==2 {
	global numvar = 12
	global iloop_pre=0
	global iloop_post=8
	global remove_contiguous_tightenings=1
	keep if dum_us==1 | dum_afe==1 
	global country_condition = "MSI>=0.25  & MSI~=." 
	global world_condition   = "INTRATEGLOBAL_HP>0.50"
	global macro_controls    = " "
	global gtitle			 = "HP-filtered Window"
}



if `imodel'==3 {
	global numvar = 12
	global iloop_pre=0
	global iloop_post=8
	global remove_contiguous_tightenings=1
	keep if dum_us==1 | dum_afe==1 | dum_eme_plus==1
	global country_condition = "MSI>=0.25  & MSI~=." 
	global world_condition   = "d4_r_global>=0.25 & (f6_r_global<0 | f6_r_global==.)"
	global macro_controls    = " "
	global gtitle			 = "AFEs and EMEs"
}



if `imodel'==4 {
	global numvar = 12
	global iloop_pre=0
	global iloop_post=8
	global remove_contiguous_tightenings=1
	keep if dum_us==1 | dum_afe==1 
	global country_condition = "MSIG>=0.25  & MSIG~=." 
	global world_condition   = "d4_r_global>=0.25 & (f6_r_global<0 | f6_r_global==.)"
	global macro_controls    = " "
	global gtitle			 = "Global Variables as Additional Controls"
}








//------------------------------------------------------------------------------
// Dummy
// INT_TIGHT / DUMT / INTRATEGLOBAL, INTW_TIGHT / DUMT_WORLD, DUMT_WORLD_MA / DUMT_GL, DUMT_LC
//------------------------------------------------------------------------------

// INT_TIGHT
gen INT_TIGHT = INTRATE if  ${country_condition}

// DUMT
gen DUMT = 0 if INTRATE~=. & INFL4~=. & d4_p~=. & d4_r~=. & d1_p~=. & d1_r~=. 
replace DUMT = 1 if INT_TIGHT==INTRATE & DUMT==0
gen DUMT_ORIGINAL = DUMT
sort country quarter
by country: gen CUMDT = cond(_n == 1 | DUMT == 0, DUMT, .) 
replace CUMDT = CUMDT[_n-1] + DUMT if missing(CUMDT) 

if $remove_contiguous_tightenings==1 {
replace DUMT = 0 if CUMDT>1 & CUMDT~=.      // Drop contiguous tightening episodes
replace DUMT = 0 if DUMT==1 & (L.DUMT==1)   // Only keep earlier tightening in one year
replace DUMT = 0 if DUMT==1 & (L2.DUMT==1)  // ...
replace DUMT = 0 if DUMT==1 & (L3.DUMT==1)  // ...
}


gen ngdp_usd_temp = ngdp_usd
replace ngdp_usd_temp = L.ngdp_usd_temp if tin(2022q1,2022q4)
egen sumgdp = sum(ngdp_usd_temp) if INTRATE~=. & ngdp_usd_temp~=., by(quarter)
gen sharegdp = ngdp_usd_temp/sumgdp if INTRATE~=. & ngdp_usd_temp~=.

// INTRATEGLOBAL 
egen INTRATEGLOBAL = sum(INTRATE*sharegdp) if INTRATE~=., by(quarter)
egen d1_r_global = sum(d1_r*sharegdp), by(quarter)
egen d4_r_global = sum(d4_r*sharegdp), by(quarter)
egen d6_r_global = sum(d6_r*sharegdp), by(quarter)
egen f1_r_global = sum(f1_r*sharegdp), by(quarter)
egen f4_r_global = sum(f4_r*sharegdp), by(quarter)
egen f6_r_global = sum(f6_r*sharegdp), by(quarter)
egen f8_r_global = sum(f8_r*sharegdp), by(quarter)

format d4_* INT_TIGHT %5.1f
list quarter d4_r d4_r_global if countrylong=="United Kingdom", sep(8) header(8)
list country sharegdp if tin(2005q1,2005q1)
//tabulate quarter, summarize(sharegdp)

// INTW_TIGHT
preserve
keep if countrylong=="United Kingdom"
keep quarter INTRATEGLOBAL 
tsset quarter
tsfilter hp INTRATEGLOBAL_HP = INTRATEGLOBAL
save output/INTRATEGLOBAL_HP.dta, replace
restore
merge m:1 quarter using output/INTRATEGLOBAL_HP.dta

gen INTW_TIGHT = INTRATE if ${world_condition}

// DUMT_WORLD
gen DUMT_WORLD = 0 if INTRATE~=. & INFL4~=. & d4_p~=. & d4_r~=. & d1_p~=. & d1_r~=. & d1_r_global~=. & d4_r_global~=.
replace DUMT_WORLD = 1 if INTW_TIGHT==INTRATE & DUMT_WORLD==0 & d1_r_global~=. & d4_r_global~=.
sort country quarter
by country: gen CUMDW = cond(_n == 1 | DUMT_WORLD == 0, DUMT_WORLD, .) 
replace CUMDW = CUMDW[_n-1] + DUMT_WORLD if missing(CUMDW) 

if $remove_contiguous_tightenings==1 {
replace DUMT_WORLD = 0 if CUMDW>1 & CUMDW~=.
replace DUMT_WORLD = 0 if DUMT_WORLD==1 & (L.DUMT_WORLD==1) 
replace DUMT_WORLD = 0 if DUMT_WORLD==1 & (L2.DUMT_WORLD==1) 
replace DUMT_WORLD = 0 if DUMT_WORLD==1 & (L3.DUMT_WORLD==1)
}


///egen DUMT_WORLD_mean = filter(DUMT_WORLD), l(-$iloop_pre/$iloop_post) normalize 
gen DUMT_WORLD_X1 = DUMT_WORLD
gen DUMT_WORLD_X2 = DUMT_WORLD
rangestat (mean) DUMT_WORLD_X1, interval(quarter -$iloop_post 0) by(country)
rangestat (mean) DUMT_WORLD_X2, interval(quarter 0 $iloop_pre) by(country)
gen DUMT_WORLD_mean = DUMT_WORLD_X1_mean + DUMT_WORLD_X2_mean
gen DUMT_WORLD_MA=1 if DUMT_WORLD_mean>0 & DUMT_WORLD_mean ~=.
replace DUMT_WORLD_MA=0 if DUMT_WORLD_mean==0 & DUMT_WORLD_mean ~=.
list country quarter DUMT_WORLD DUMT_WORLD_MA DUMT_WORLD_X1_mean DUMT_WORLD_X2_mean if countrylong=="United Kingdom"


// DUMT_GL, DUMT_LC
replace DUMT=. if DUMT_WORLD_MA==.
gen DUMT_GL = 0 if DUMT~=. & DUMT_WORLD_MA~=.
replace DUMT_GL = 1 if DUMT==1 & DUMT_WORLD_MA>0 & DUMT_WORLD_MA~=.
gen DUMT_LC = 0 if DUMT~=. & DUMT_WORLD_MA~=.
replace DUMT_LC = 1 if DUMT==1 & DUMT_WORLD_MA==0 & DUMT_WORLD_MA~=.

// Replace Global Tightening dummy to missing for experiments where we remove one period at the time and remove_condition is met
replace DUMT_GL = . if `imodel'>10 & `imodel'<99 ${remove_condition}


gen DUMT_OT = 0 if DUMT~=.
replace DUMT_OT = 1 if DUMT==0 & DUMT_WORLD==1


label var DUMT          "DUMMY=1 if country is tightening"
label var DUMT_GL 	    "DUMMY=1 if country is in synchronous tightening"
label var DUMT_LC 	    "DUMMY=1 if country is in asynchronous tightening"
label var DUMT_OT 	    "DUMMY=1 if world is tightening, country is not"
label var DUMT_WORLD    "DUMMY=1 if world is tightening in t"
label var DUMT_WORLD_MA "DUMMY=1 if world is in a tightening cycle"
compress DUMT*





levelsof countrylong, local(idlist) clean
global gidlist_c `idlist'

levelsof quarter_text if DUMT==1 &  countrylong=="United States", local(idlist) clean
global gidlist_us `idlist' 
di as text "$gidlist_us"

levelsof quarter_text if DUMT_WORLD==1 &  countrylong=="United States", local(idlist) clean
global gidlist_world `idlist'
di as text "$gidlist_world"


gen ngdp_usd_temp_nous = ngdp_usd_temp
replace ngdp_usd_temp_nous=0 if dum_us==1
egen sum_gdp_ex_us_taylor = sum(ngdp_usd_temp_nous) if MSI~=. & ngdp_usd_temp_nous~=., by(quarter)
gen share_gdp_ex_us_taylor = ngdp_usd_temp_nous/sum_gdp_ex_us_taylor if MSI~=. & ngdp_usd_temp_nous~=.
egen MSI_ROW = sum(MSI*share_gdp_ex_us_taylor) if MSI~=. & share_gdp_ex_us_taylor~=., by(quarter)




summarize INTRATEGLOBAL
generate DUMT_WORLD_MA_shade = r(max) if DUMT_WORLD_MA == 1 & countrylong=="United Kingdom"
replace  DUMT_WORLD_MA_shade = r(min) if DUMT_WORLD_MA == 0 & countrylong=="United Kingdom"
local min = r(min)

gen INTRATEGLOBAL_PLOT=INTRATEGLOBAL+0.1


// if $do_global_interest_rates_plot == 1 {
//
//
//	
//	
// 	graph twoway ///
// 	(area DUMT_WORLD_MA_shade quarter if countrylong=="United Kingdom",  color(red%20) base(`min')) ///
// 	(tsline  INTRATEGLOBAL if countrylong=="United Kingdom", lcolor(black%90) lwidth(0.6) ///
// 	title("Global Interest Rates and Global Tightening Episodes") ///
// 	tlabel($gidlist_world, labsize(*0.9)) ///
// 	ytitle("") ///
// 	legend(off) xsize(3) ysize(1.7) /// 
// 	ylabel(0 2 4 6 8 10 12, angle(horizontal) format(%5.0f))  ///
// 	name(AA_`imodel', replace) xtitle("")  graphregion(fcolor(white))) 
//
// 	drop INTRATEGLOBAL_PLOT
//	
// 	graph export output/GLOBRATES_`imodel'.pdf, name(AA_`imodel') replace logo(off) mag(100) 
//
//
// 	if `imodel'==2 {	
//	
// 	gen INTRATEGLOBAL_TREND = INTRATEGLOBAL - INTRATEGLOBAL_HP
//	
// 	graph twoway ///
// 	(area DUMT_WORLD_MA_shade quarter if countrylong=="United Kingdom",  color(red%20) base(`min')) ///
// 	(tsline  INTRATEGLOBAL_TREND if countrylong=="United Kingdom", lcolor(blue%90) lwidth(0.6)) ///
// 	(tsline  INTRATEGLOBAL if countrylong=="United Kingdom", lcolor(black%90) lwidth(0.6) ///
// 	title("Global Interest Rates and Global Tightening Episodes") ///
// 	tlabel($gidlist_world, labsize(*0.9)) ///
// 	ytitle("") ///
// 	legend(off) xsize(3) ysize(1.3) /// 
// 	ylabel(0 2 4 6 8 10 12, angle(horizontal) format(%5.0f))  ///
// 	name(AA_`imodel', replace) xtitle("")  graphregion(fcolor(white))) 
//
// 	graph export output/GLOBRATES_`imodel'.pdf, name(AA_`imodel') replace logo(off) mag(100) 
//	
// 	}	
//
//
// 	foreach icountry of numlist 1 2 3 4 5 6 7 8 9 { 
//
// if `icountry'== 1 {
// 	global countryname "United States"
// }
// if `icountry'== 2 {
// 	global countryname "France"
// }
// if `icountry'== 3 {
// 	global countryname "Germany"
// }
// if `icountry'== 4 {
// 	global countryname "Italy"
// }
// if `icountry'== 5 {
// 	global countryname "Canada"
// }
// if `icountry'== 6 {
// 	global countryname "Spain"
// }
// if `icountry'== 7 {
// 	global countryname "Sweden"
// }
// if `icountry'== 8 {
// 	global countryname "United Kingdom"
// }
// if `icountry'== 9 {
// 	global countryname "Australia"
// }
//
// di "----------------------------"
// di `icountry'
// di `"$countryname"'
// di "Global"
// levelsof quarter_text if DUMT_GL==1 & countrylong==`"$countryname"', local(idlist) clean
// cap global gidlist_gl `idlist' 
// di "Local"
// levelsof quarter_text if DUMT_LC==1 & countrylong==`"$countryname"', local(idlist) clean
// cap global gidlist_lc `idlist' 
//
//
//
// tsline  INTRATE INFL4 UNEMPLO if countrylong==`"$countryname"', lcolor(black%90 orange%90 blue%50) lwidth(0.6 0.6) ///
// title($countryname, size(small)) ///
// legend(label (1 "R") label(2 "DP") label(3 "u") rows(3) ring(0) position(2) symysize(*.3) symxsize(*.3) rowgap(0.01) size(tiny)) ///
// tlabel($t1p(40)$t2p) ///
// tline($gidlist_gl, lcolor(red)) ///
// tline($gidlist_lc, lcolor(blue)) ///
// ylabel(, angle(horizontal) format(%5.0f))  ///
// name(AA`icountry', replace) xtitle("")  graphregion(fcolor(white)) nodraw
//
//
// }
//
//
// graph combine AA1 AA2 AA3 AA4 AA5 AA6 AA7 AA8 AA9, ///
// title("") iscale(0.65) name(EP_`imodel', replace) rows(3) xsize(3) ysize(2)  graphregion(fcolor(white)) 
//
//
// }

sort country quarter




egen n_int = count(DUMT), by(country)
egen n_tight = sum(DUMT), by(country)
egen n_tight_gl = sum(DUMT_GL), by(country)

egen t_int = sum(DUMT)
egen t_tight = sum(DUMT)
egen t_tight_gl = sum(DUMT_GL)

egen t_tight_lc = sum(DUMT_LC)

list country n_int n_tight  n_tight_gl if tin(2010q1,2010q1)
list country t_int t_tight  t_tight_lc t_tight_gl if tin(2010q1,2010q1)

egen totperiods = count(DUMT), by(quarter)
egen totshocks = sum(DUMT), by(quarter)
egen totshocks_gl = sum(DUMT_GL), by(quarter)


list country quarter DUMT DUMT_WORLD_MA if countrylong=="United Kingdom" 

tabulate DUMT if dum_us==1 & tin($t1p,$t2p)
tabulate DUMT if dum_us==0 & DUMT_GL==1 & tin($t1p,$t2p)
tabulate DUMT if dum_us==0 & DUMT_GL==0 & tin($t1p,$t2p)

list country quarter DUMT DUMT_LC DUMT_GL DUMT_WORLD DUMT_WORLD_MA if countrylong=="United States", header(8)




//---------------------------
// RUN Analysis
//---------------------------

foreach ii of numlist 1/$numvar {

	if `ii'==1 {
	global YVAL "INTRATE"
	global yvarunits "p.p."
	global YVALTITLE "Interest Rate"
	global ymin = -1.5
	global ymax = 2	
	global yformat = "%5.0f"
	}
	if `ii'==2 {
	global YVAL "GDPVAR"
	global YVALTITLE "GDP"
	global yvarunits "percent"
	global ymin = -3
	global ymax = 1	
	global yformat = "%5.0f"
	}
	if `ii'==3 {
	global YVAL "UNEMPLO"
	global YVALTITLE "Unemployment"
	global yvarunits "p.p."
	global ymin = -0.5
	global ymax = 1.5	
	global yformat = "%5.1f"
	}
	if `ii'==4 {
	global YVAL "INFL4"
	global YVALTITLE "Inflation"
	global yvarunits "p.p."
	global ymin = -1
	global ymax = 1	
	global yformat = "%5.1f"
	}
	if `ii'==5 {
	global YVAL "SPREAD"
	global YVALTITLE "Corporate Spreads"
	global yvarunits "bps"
	global ymin = -40
	global ymax = 100
	global yformat = "%5.0f"
	}
	if `ii'==6 {
	global YVAL "BANKNW"
	global YVALTITLE "Banks Equity Prices"
	global yvarunits "percent"
	global ymin = -30
	global ymax = 10	
	global yformat = "%5.0f"
	}
	if `ii'==7 {
	global YVAL "CONSVAR"
	global YVALTITLE "Consumption"
	global yvarunits "percent"
	global ymin = -1
	global ymax = 1	
	global yformat = "%5.0f"
	}
	if `ii'==8 {
	global YVAL "INVVAR"
	global YVALTITLE "Investment"
	global yvarunits "percent"
	global ymin = -1
	global ymax = 1	
	global yformat = "%5.0f"
	}
	if `ii'==9 {
	global YVAL "XRVAR"
	global YVALTITLE "Real Exchange Rate"
	global yvarunits "Percent"
	global ymin = -1
	global ymax = 1	
	global yformat = "%5.1f"
	}
	if `ii'==10 {
	global YVAL "NXVAR"
	global YVALTITLE "Net Exports/GDP"
	global yvarunits "p.p."
	global ymin = -1
	global ymax = 1	
	global yformat = "%5.1f"
	}
	if `ii'==11 {
	global YVAL "NXTRADEVAR"
	global YVALTITLE "Net Exports/Trade"
	global yvarunits "p.p."
	global ymin = -1
	global ymax = 1	
	global yformat = "%5.1f"
	}
	if `ii'==12 {
	global YVAL "TRADEGDPVAR"
	global YVALTITLE "Trade/GDP"
	global yvarunits "p.p."
	global ymin = -1
	global ymax = 1	
	global yformat = "%5.0f"
	}

	if `"$gtitle"' == "AFEs and EMEs" & `ii'==5 {
	global YVALTITLE "Corp./Sovr.Spreads"
	}



	///------------------------------------------
	/// EVENT STUDY
	///------------------------------------------

		cap drop F*DUMT*
		cap drop L*DUMT*

		forvalues i=1/$periodnum_pre {
		local j=$periodnum_pre+1-`i'
		quietly gen F`j'DUMT = F`j'.DUMT 
		quietly gen F`j'DUMT_GL = F`j'.DUMT_GL 
		quietly gen F`j'DUMT_LC = F`j'.DUMT_LC 
		}
		forvalues i=0/$periodnum_post {
		quietly gen L`i'DUMT = L`i'.DUMT 
		quietly gen L`i'DUMT_GL = L`i'.DUMT_GL 
		quietly gen L`i'DUMT_LC = L`i'.DUMT_LC 
		}


		quietly gen bet_GL_$YVAL = .
		quietly gen bet_GL_se_$YVAL = .
		quietly gen bet_LC_$YVAL = .
		quietly gen bet_LC_se_$YVAL = .

		///------------------
		/// RUN REGRESSION
		///------------------
		quietly reghdfe $YVAL ///
		F*DUMT_GL L*DUMT_GL F*DUMT_LC L*DUMT_LC ${macro_controls} ///
		if tin($t1,$t2) & dum_o==1, ab(country) vce(cl country quarter)

		forvalues i=-$periodnum_pre/$periodnum_post {

		if `i'<0 {
		local j = -`i'
		quietly replace bet_GL_$YVAL 		=   _b[F`j'DUMT_GL]   if quarter == quarterly("2015q1", "YQ") + `i'
		quietly replace bet_GL_se_$YVAL 	=  _se[F`j'DUMT_GL]   if quarter == quarterly("2015q1", "YQ") + `i'
		quietly replace bet_LC_$YVAL 		=   _b[F`j'DUMT_LC]   if quarter == quarterly("2015q1", "YQ") + `i'
		quietly replace bet_LC_se_$YVAL 	=  _se[F`j'DUMT_LC]   if quarter == quarterly("2015q1", "YQ") + `i'
		}

		if `i'>=0 {
		quietly replace bet_GL_$YVAL 		=   _b[L`i'DUMT_GL]   if quarter == quarterly("2015q1", "YQ") + `i'
		quietly replace bet_GL_se_$YVAL 	=  _se[L`i'DUMT_GL]   if quarter == quarterly("2015q1", "YQ") + `i'
		quietly replace bet_LC_$YVAL 		=   _b[L`i'DUMT_LC]   if quarter == quarterly("2015q1", "YQ") + `i'
		quietly replace bet_LC_se_$YVAL 	=  _se[L`i'DUMT_LC]   if quarter == quarterly("2015q1", "YQ") + `i'
		}

		}

		sum bet_LC_$YVAL if quarter == quarterly("2015q1", "YQ")-1
		quietly gen LC_$YVAL =  bet_LC_$YVAL - `r(mean)'

		sum bet_GL_$YVAL if quarter == quarterly("2015q1", "YQ")-1
		quietly gen GL_$YVAL =  bet_GL_$YVAL - `r(mean)'

		quietly gen LC_UB_$YVAL = LC_$YVAL + bet_LC_se_$YVAL
		quietly gen LC_LB_$YVAL = LC_$YVAL - bet_LC_se_$YVAL
		quietly gen GL_UB_$YVAL = GL_$YVAL + bet_GL_se_$YVAL
		quietly gen GL_LB_$YVAL = GL_$YVAL - bet_GL_se_$YVAL
		
		quietly replace LC_UB_$YVAL = 0 if quarter == quarterly("2015q1", "YQ")-1
		quietly replace LC_LB_$YVAL = 0 if quarter == quarterly("2015q1", "YQ")-1
		quietly replace GL_UB_$YVAL = 0 if quarter == quarterly("2015q1", "YQ")-1
		quietly replace GL_LB_$YVAL = 0 if quarter == quarterly("2015q1", "YQ")-1

		









preserve
keep if countrylong=="United Kingdom" & LC_INTRATE~=.
gen h=-$periodnum_pre
replace h=h+_n-1
gen zeroline = 0

twoway ///
(line zeroline h, color(black) lwidth(.2)) ///
(line LC_$YVAL h, color(blue) lwidth(.5) lpattern(dash)) ///
(rarea LC_LB_$YVAL LC_UB_$YVAL h, fcolor(blue%20) lcolor(white%0)) ///
(line GL_$YVAL h, color(red) lwidth(.7)) ///
(rarea GL_LB_$YVAL GL_UB_$YVAL h, fcolor(red%20) lcolor(white%0)), ///
xsc(r(-$periodnum_pre $periodnum_post)) ///
ysc(r($ymin $ymax)) ///
xlab(-$periodnum_pre(2)$periodnum_post) ///
ylabel(, angle(horizontal) format($yformat) ) ///
ytitle($yvarunits) ///
xtitle("quarters")  ///
legend(off) ///
title($YVALTITLE, size(*0.87)) name(G`ii'_`imodel', replace) nodraw  graphregion(fcolor(white)) 

restore

}

save output/dataset_`imodel', replace




// When I do GDP components, only plot subset of variables
if $do_event_study_plot==1 & $numvar==12 {
	
graph combine G1_`imodel' G2_`imodel' G3_`imodel' G4_`imodel' G5_`imodel' ///
G6_`imodel' G7_`imodel' G8_`imodel' G9_`imodel' G10_`imodel' G11_`imodel' G12_`imodel', ///
title($gtitle, size(*0.55)) rows(3) name(ESY_`imodel', replace) fxsize(120) iscale(0.57) imargin(small)
graph export output/ESY_`imodel'.pdf, name(ESY_`imodel') replace logo(off) mag(100) 

}




}









if $do_global_rates_plot == 1 {
	
use output/dataset_1, clear

sum INTRATE INFL4 GDPVAR UNEMPLO NXVAR CONSVAR INVVAR XRVAR BANKNW SPREAD if dum_o==1 & tin($t1,$t3)

levelsof quarter_text if DUMT_WORLD==1 &  countrylong=="United Kingdom", local(idlist) clean
global gidlist_world `idlist'
di as text "$gidlist_world"

pwcorr MSI MPSHOCK_RR_US if countrylong=="United States"
pwcorr MSI MPSHOCK_LIT if countrylong=="Canada"
pwcorr MSI MPSHOCK_CH_UK if countrylong=="United Kingdom"
pwcorr MSI MPSHOCK_LIT if countrylong=="Norway"

xttab country if dum_o==1 & tin($t1,$t3)
xttab country if dum_o==1 & DUMT==1 & tin($t1,$t3)
xttab country if dum_o==1 & DUMT_GL==1 & tin($t1,$t3)
xttab country if dum_o==1 & DUMT_LC==1 & tin($t1,$t3)
levelsof quarter_text if DUMT==1 & tin($t1,$t3) &  countrylong=="United States", local(idlist) clean
levelsof quarter_text if DUMT_GL==1 & tin($t1,$t3) &  countrylong=="United States", local(idlist) clean
levelsof quarter_text if DUMT_LC==1 & tin($t1,$t3) &  countrylong=="United States", local(idlist) clean

sort quarter country
list country quarter DUMT_LC DUMT_GL DUMT_WORLD DUMT_WORLD_MA if ((DUMT_LC==1 | DUMT_GL==1) & DUMT~=.)

global t1 "1980q1"
global t2 "2022q4"

gen DUM_INT_RISE_CHART = 0 if d4_r~=.
replace DUM_INT_RISE_CHART = 1 if d4_r>=0.25 & d4_r~=.

egen N_COUNTRIES = count(DUM_INT_RISE_CHART)		    if DUM_INT_RISE_CHART~=., by(quarter)
egen N_RISE = sum(DUM_INT_RISE_CHART) 					if DUM_INT_RISE_CHART~=., by(quarter)

egen N_COUNTRIES_AE = count(DUM_INT_RISE_CHART)		    if DUM_INT_RISE_CHART~=. & (dum_us==0), by(quarter)
egen N_RISE_AE = sum(DUM_INT_RISE_CHART) 				if DUM_INT_RISE_CHART~=. & (dum_us==0), by(quarter)

gen SHARE_RISE = N_RISE/N_COUNTRIES
gen SHARE_RISE_AE = N_RISE_AE/N_COUNTRIES_AE

summarize INTRATEGLOBAL
local min = r(min)
cap drop INTRATEGLOBAL_PLOT
gen INTRATEGLOBAL_PLOT=INTRATEGLOBAL+0.2 // The 0.2 is just shifting the plot to make the shaded region prettier in Stata


graph twoway ///
(area DUMT_WORLD_MA_shade quarter if countrylong=="United Kingdom",  color(red%20) base(`min')) ///
(tsline  INTRATEGLOBAL_PLOT if countrylong=="United Kingdom", lcolor(black%90) lwidth(0.6) ///
title("Global Interest Rates") ///
tlabel($gidlist_world 2022q4, labsize(small)) ///
ytitle("") ///
legend(off) /// 
ylabel(0 2 4 6 8 10 12, angle(horizontal) format(%5.0f))  ///
name(AAS, replace) xtitle("")  nodraw graphregion(fcolor(white))) 


preserve
keep if countrylong=="United States"
keep quarter SHARE_RISE N_RISE N_COUNTRIES SHARE_RISE_AE N_RISE_AE N_COUNTRIES_AE DUMT_WORLD DUMT_WORLD_MA
export delimited using output/share_rise.xls, replace

gen SHARE_RISE_100=SHARE_RISE*100
graph twoway ///
(bar SHARE_RISE_100 quarter, yscale(r(0 1)) color(blue%20)) ///
(tsline SHARE_RISE_100, lcolor(blue) lwidth(0.4) ysc(r(0 1)) title("Share of Countries with Rising Interest Rates") ///
tlabel($gidlist_world 2022q4, labsize(small)) ///
ylabel(, angle(horizontal) format(%5.0f))  ///
legend(off) /// 
name(AAX, replace) xtitle("") ytitle("") nodraw graphregion(fcolor(white))) 
restore


graph combine AAS AAX, ///
title("") iscale(0.75) name(FIG1, replace) rows(2) xsize(3) ysize(2)  graphregion(fcolor(white)) 
graph export output/GLOBRATES.pdf, name(FIG1) replace logo(off) mag(100) 
	
	
}





if $do_global_rates_plot_hp == 1 {
	
	use output/dataset_2, clear

 	gen INTRATEGLOBAL_TREND = INTRATEGLOBAL - INTRATEGLOBAL_HP
	
 	graph twoway ///
 	(area DUMT_WORLD_MA_shade quarter if countrylong=="United Kingdom",  color(red%20) base(`min')) ///
 	(tsline  INTRATEGLOBAL_TREND if countrylong=="United Kingdom", lcolor(blue%90) lwidth(0.6)) ///
 	(tsline  INTRATEGLOBAL if countrylong=="United Kingdom", lcolor(black%90) lwidth(0.6) ///
 	title("Global Interest Rates and Global Tightening Episodes") ///
 	tlabel($gidlist_world, labsize(*0.9)) ///
 	ytitle("") ///
 	legend(off) xsize(3) ysize(1.3) /// 
 	ylabel(0 2 4 6 8 10 12, angle(horizontal) format(%5.0f))  ///
 	name(APPFIG2TOP, replace) xtitle("")  graphregion(fcolor(white))) 
 	graph export output/GLOBRATES_2.pdf, name(APPFIG2TOP) replace logo(off) mag(100) 

	
}
