// Version JME December 15, 2023

clear
set more off
set scheme s1color, permanently
eststo clear
capture mkdir output

// FOR REGRESSIONS
global t1 "1980q1"
global t2 "2019q4"

cap drop sum_weight*


foreach ii of numlist 1 { 



	set seed 0
	use macrodata_newcore, clear
	
	gen DOIL = oil_usd/L4.oil_usd-1

	gen XRVAR = 100*log(reer_bruegel)
	
	tabulate country if dum_afe==0 & dum_eme_plus==0, summarize(INTRATE)
	tabulate country if dum_eme_plus==1, summarize(INTRATE)
	tabulate country if dum_afe==0 & dum_eme_plus==0, summarize(INTRATE)
	
	keep if dum_us==1 | dum_afe==1 


	keep if tin($t1,$t2)
	
	
	gen LGDP = 100*ln_gdp
	sort country quarter             
	gen DGDP = D.LGDP

	gen D4GDP = LGDP - L4.LGDP
	by country: egen lowGDP = pctile(D4GDP) if D4GDP~=., p(50)
	gen BADSTATE = 0 if D4GDP~=.
	replace BADSTATE = 1 if D4GDP<lowGDP
	
	
	/// CONSTRUCT GLOBAL VARIABLES
	gen weight = ngdp_usd
	replace weight = L.weight if tin(2022q1,2022q4)



	// Country Taylor rule regressions, 2 lags
	quietly reg INTRATE ///
	i.country ///
	i.country#c.quarter ///
	i.country#c.quarter#c.quarter ///
	i.country#c.L(1/2).DOIL ///
	i.country#c.L(1/2).INTRATE ///
	i.country#c.L(1/2).UNEMPLO ///
	i.country#c.L(1/2).XRVAR ///
	i.country#c.L(1/2).INFL4 ///
	if tin($t1,$t2)
	quietly predict MSI if e(sample), residuals
	label var MSI "Monetary Shock from Taylor rule (2 lags), ppt"
	
	sum MSI if MSI>0
	sum MSI if MSI<0

	if `ii'==1 {
		global msit = 0.0
	}


	




	foreach v in ///
		INTRATE INFL4 UNEMPLO DGDP MSI BADSTATE D4GDP {
		cap drop sum_weight*
		cap drop share_weight*
		egen sum_weight_`v' = sum(weight) if `v'~=. & weight~=., by(quarter)
		gen share_weight_`v' = weight/sum_weight_`v'
		asgen `v'_WORLD = `v' if `v'~=., weights(share_weight_`v') by(quarter)
		gen `v'_ROW = 1/(1-share_weight_`v')*`v'_WORLD - share_weight_`v'/(1-share_weight_`v')*`v'
	}

	bysort country (quarter) : gen LGDP_WORLD = sum(DGDP_WORLD) if DGDP_WORLD~=.
	label var LGDP_WORLD "log GDP World"
	bysort country (quarter) : gen LGDP_ROW = sum(DGDP_ROW) if DGDP_ROW~=.
	label var LGDP_ROW "log GDP ROW"

	sort country quarter
	gen YY = 	 F8.LGDP 	 - LGDP
	gen PP = 	 F8.INFL4 	 - INFL4

	format YY* %5.1f
	format MS* %5.2f
	format INT* %5.2f


	

	// For each country
	gen DUM_MSI = 0 if MSI~=.
	replace DUM_MSI = 1 if MSI~=. & MSI>$msit
	gen MSIPOS = max($msit,MSI)
	gen MSINEG = min($msit,MSI)
	gen MSIROWPOS = max($msit,MSI_ROW)
	gen MSIROWNEG = min($msit,MSI_ROW)
	gen DUM_MSI_ROW = 0 if MSI_ROW~=.
	replace DUM_MSI_ROW = 1 if MSI_ROW~=. & MSI_ROW>$msit

	eststo clear


 	global bootstrap = "vce(bootstrap, reps(50))"
	eststo: xtreg   YY  DUM_MSI DUM_MSI_ROW, fe $bootstrap
	eststo: xtreg   YY  DUM_MSI DUM_MSI_ROW c.DUM_MSI#c.DUM_MSI_ROW, fe $bootstrap
	eststo: xtreg   YY  DUM_MSI DUM_MSI_ROW i.BADSTATE#c.DUM_MSI#c.DUM_MSI_ROW, fe $bootstrap

	esttab, b(%5.2f) starlevels(* 0.10 ** 0.05 *** 0.01) nocon varwidth(34)



	esttab using output/table1.tex, b(%5.2f) starlevels(* 0.10 ** 0.05 *** 0.01) ///
	replace label nocon ///
	title(\label{table:spilloverequations}Spillovers of Monetary Shocks)
	
	



global bootstrap = ""
xtreg   YY  c.DUM_MSI i.DUM_MSI_ROW c.BADSTATE#c.DUM_MSI#i.DUM_MSI_ROW, fe $bootstrap

margins DUM_MSI_ROW, at(DUM_MSI=(0 1) BADSTATE=(0 1)) cformat(%6.2f)




marginsplot, ///
ytitle("GDP growth two years ahead") ///
ylabel(, angle(horizontal)) ///
xtitle("Domestic Easing 0 or Tightening 1") ///
legend(off) ///
level(90) ///
title("Effects of Domestic Tightening Events") ///
text(5.65 0.59 "{bf:High Growth, Foreign Easing}", color(green)) ///
text(4.87 0.72 "{bf:Low Growth, Foreign Easing}", color(navy)) ///
text(4.12 0.55 "{bf:High Growth, Foreign Tightening}", color(orange)) ///
text(3.18 0.45 "{bf:Low Growth, Foreign Tightening}", color(maroon)) ///
recast(line) recastci(rarea) ciopt(color(%10)) plotopts(lwidth(thick)) name(ME`ii', replace)


graph export output/marginal_effects.pdf, name(ME`ii') replace logo(off) mag(100) 



}



